@@ -1,11 +1,15 @@
-'use strict';
-const defaults = require('./default');
-const OptionHelper = require('./OptionHelper');
+"use strict";
+
+const defaults = require("./default");
+const OptionHelper = require("./OptionHelper");
 
 class WebpackOptionHelper extends OptionHelper {
-
   getDefaultOptions() {
-    return Object.assign({}, defaults.gruntOptions, defaults.webpackDevServerOptions);
+    return Object.assign(
+      {},
+      defaults.gruntOptions,
+      defaults.webpackDevServerOptions,
+    );
   }
 
   getWebpackOptions() {
